@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,13 +11,12 @@
 #
 ##############################################################################
 """ Unit tests for browser module.
-
-$Id: tests.py 104367 2009-09-18 22:43:32Z tseaver $
 """
 
 import unittest
 from Testing import ZopeTestCase
-from Products.Five.schema import Zope2VocabularyRegistry
+
+from Zope2.App.schema import Zope2VocabularyRegistry
 
 from Products.CMFCalendar.testing import FunctionalLayer
 
@@ -39,7 +38,3 @@ def test_suite():
     s.layer = FunctionalLayer
     suite.addTest(s)
     return suite
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
