@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """ Unit tests for CalendarTool module.
-
-$Id: test_Calendar.py 101692 2009-07-07 11:58:11Z yuppie $
 """
 
 import unittest
@@ -22,7 +20,6 @@ ZopeTestCase.utils.setupCoreSessions()
 import locale
 
 from AccessControl.SecurityManagement import newSecurityManager
-from AccessControl.User import UnrestrictedUser
 from DateTime import DateTime
 from zope.interface.verify import verifyClass
 from zope.site.hooks import setSite
@@ -108,9 +105,12 @@ class CalendarRequestTests(ZopeTestCase.FunctionalTestCase):
     layer = FunctionalLayer
 
     def afterSetUp(self):
-        setSite(self.app.site)
-        self.app.site.setupCurrentSkin(self.app.REQUEST)
-        newSecurityManager(None, UnrestrictedUser('god', '', ['Manager'], ''))
+        site = self.app.site
+        setSite(site)
+        site.setupCurrentSkin(self.app.REQUEST)
+        site.acl_users._doAddUser('god', 'secret', ['Manager'], [])
+        user = site.acl_users.getUser('god').__of__(site.acl_users)
+        newSecurityManager(None, user)
 
         # sessioning setup
         sdm = self.app.session_data_manager
@@ -788,7 +788,3 @@ def test_suite():
         unittest.makeSuite(CalendarTests),
         unittest.makeSuite(CalendarRequestTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
